"""
Tests for casa_envoy.palaver
"""
import argparse
from unittest.mock import patch, MagicMock

import casa_envoy.palaver as palaver

expected_settings = {
    "useCasa": False,
    "homeForReprocessing": "/home/casa/packages/pipeline/current",
    "rootDirectory": "/lustre/aoc/cluster/pipeline/docker/workspaces/spool",
    "processingDirectory": "tmpo1ca1pp_",
    "parent_path": "/lustre/aoc/cluster/pipeline/docker/workspaces/spool/tmpo1ca1pp_",
    "metadata": "test/input_files/test.json",
    "ppr": "test/input_files/PPR.xml",
    "product_type": "standard-cal",
}
args = argparse.Namespace()


class TestPalaver:
    def test_get_settings(self):
        args.standard_cal = ["test/input_files/test.json", "test/input_files/PPR.xml"]
        args.restore = False

        with patch(
            "pathlib.Path.cwd",
            MagicMock(
                return_value="/lustre/aoc/cluster/pipeline/docker/workspaces/spool/tmpo1ca1pp_"
            ),
        ) as cwd:
            settings = palaver._get_settings(cwd, args.standard_cal)
            assert settings["useCasa"] == expected_settings["useCasa"]
            assert settings["homeForReprocessing"] == expected_settings["homeForReprocessing"]
            assert settings["metadata"] == expected_settings["metadata"]
            assert settings["ppr"] == expected_settings["ppr"]

        args.standard_cal = None

    @patch("os.chdir")
    @patch("os.getcwd")
    def test_main_cal(self, mock_cwd, mock_chdir):
        args.standard_cal = ["test/input_files/test.json", "test/input_files/PPR.xml"]
        args.integrated = False

        with patch("argparse.ArgumentParser.parse_args", MagicMock(return_value=args)) as mock_args:
            with patch("casa_envoy.launchers.CalibrationLauncher.launch_casa") as cal_launcher:
                palaver.main()
                assert cal_launcher.call_count == 1

        args.standard_cal = None

    @patch("os.chdir")
    @patch("os.getcwd")
    def test_main_img(self, mock_cwd, mock_chdir):
        args.standard_img = [
            "test/input_files/image-metadata.json",
            "test/input_files/cmsimage-PPR.xml",
        ]

        with patch("argparse.ArgumentParser.parse_args", MagicMock(return_value=args)) as mock_args:
            with patch("casa_envoy.launchers.ImagingLauncher.launch_casa") as img_launcher:
                palaver.main()
                assert img_launcher.call_count == 1

        args.standard_img = None
